@@ -3,7 +3,8 @@ package DateTime::Format::Natural;
 use strict;
 use warnings;
 use base qw(
-    DateTime::Format::Natural::Base
+    DateTime::Format::Natural::Aliases
+    DateTime::Format::Natural::Calc
     DateTime::Format::Natural::Duration
     DateTime::Format::Natural::Formatted
     DateTime::Format::Natural::Helpers
@@ -12,12 +13,12 @@ use boolean qw(true false);
 
 use Carp qw(croak);
 use DateTime ();
-use List::MoreUtils qw(all any);
+use List::MoreUtils qw(all any none);
 use Params::Validate ':all';
 use Scalar::Util qw(blessed);
 use Storable qw(dclone);
 
-our $VERSION = '0.83';
+our $VERSION = '0.88';
 
 validation_options(
     on_fail => sub
@@ -63,7 +64,7 @@ sub _init
     $self->{Daytime} = $opts{daytime} || {};
 
     my $mod = __PACKAGE__.'::Lang::'.uc($self->{Lang});
-    eval "use $mod"; die $@ if $@;
+    eval "require $mod"; die $@ if $@;
 
     $self->{data} = $mod->__new();
     $self->{grammar_class} = $mod;
@@ -77,7 +78,7 @@ sub _init_check
         lang => {
             type => SCALAR,
             optional => true,
-            regex => qr!^(?:en)$!,
+            regex => qr!^(?:en)$!i,
         },
         format => {
             type => SCALAR,
@@ -122,9 +123,7 @@ sub _init_vars
 {
     my $self = shift;
 
-    foreach my $member (qw(modified postprocess)) {
-        delete $self->{$member};
-    }
+    delete @$self{qw(modified postprocess)};
 }
 
 sub parse_datetime
@@ -133,9 +132,11 @@ sub parse_datetime
 
     $self->_parse_init(@_);
 
-    $self->{Input_string} = $self->{Date_string};
+    $self->{input_string} = $self->{date_string};
 
-    my $date_string = $self->{Date_string};
+    my $date_string = $self->{date_string};
+
+    $self->_rewrite_aliases(\$date_string);
     $date_string =~ tr/,//d;
 
     my ($formatted) = $date_string =~ m!^((?:\d+?[-./])+ (?:\d+?)) \b!x;
@@ -161,6 +162,24 @@ sub parse_datetime
             $self->_advance_future(qw(md));
         }
     }
+    elsif ($date_string =~ /^([+-]) (\d+?) ([a-zA-Z]+)$/x) {
+        my ($prefix, $value, $unit) = ($1, $2, lc $3);
+
+        my %methods = (
+            '+' => '_add',
+            '-' => '_subtract',
+        );
+        my $method = $methods{$prefix};
+
+        if (none { $unit =~ /^${_}s?$/ } @{$self->{data}->__units('ordered')}) {
+            $self->_set_failure;
+            $self->_set_error("(invalid unit)");
+            return $self->_get_datetime_object;
+        }
+        $self->$method($unit => $value);
+
+        $self->_set_valid_exp;
+    }
     else {
         @{$self->{tokens}} = split /\s+/, $date_string;
         $self->{data}->__init('tokens')->($self);
@@ -199,7 +218,7 @@ sub _parse_init
 {
     my $self = shift;
 
-    $self->_params_init(@_, { string => \$self->{Date_string} });
+    $self->_params_init(@_, { string => \$self->{date_string} });
 
     my $set_datetime = sub
     {
@@ -264,12 +283,10 @@ sub parse_datetime_duration
     $self->_post_duration(\@queue);
     $self->_restore_state;
 
-    foreach my $member (qw(duration formatted insert state)) {
-        delete $self->{$member};
-    }
+    delete @$self{qw(duration insert state)};
 
     @{$self->{traces}} = @traces;
-    $self->{Input_string} = $duration_string;
+    $self->{input_string} = $duration_string;
 
     return @queue;
 }
@@ -287,7 +304,7 @@ sub error
 
     return '' if $self->success;
 
-    my $error  = "'$self->{Input_string}' does not parse ";
+    my $error  = "'$self->{input_string}' does not parse ";
        $error .= $self->_get_error || '(perhaps you have some garbage?)';
 
     return $error;
@@ -467,7 +484,7 @@ sub _unset_trace     { @{$_[0]->{trace}} = ()                 }
 
 sub _get_error       { $_[0]->{error}         }
 sub _set_error       { $_[0]->{error} = $_[1] }
-sub _unset_error     { $_[0]->{error} = ''    }
+sub _unset_error     { $_[0]->{error} = undef }
 
 sub _get_failure     { $_[0]->{failure}         }
 sub _set_failure     { $_[0]->{failure} = true  }
@@ -482,7 +499,7 @@ sub _get_datetime_object
     my $self = shift;
 
     my $dt = DateTime->new(
-        time_zone => $self->{datetime}->time_zone->name,
+        time_zone => $self->{datetime}->time_zone,
         year      => $self->{datetime}->year,
         month     => $self->{datetime}->month,
         day       => $self->{datetime}->day_of_month,
@@ -695,6 +712,9 @@ valuable suggestions and patches:
  Christian Brink
  Giovanni Pensa
  Andrew Sterling Hanenkamp
+ Eric Wilhelm
+ Kevin Field
+ Wes Morgan
 
 =head1 SEE ALSO
 
